@@ -449,6 +449,18 @@ class ObjectStorageContext(ObjectStorageContextFileMixin):
         """
         raise NotImplementedError()
 
+    @abstractmethod
+    def getSingularItem(self, group: ItemStorageGroupEnum) -> StorageTuple:
+        """Get Singular Item
+
+        Get item from `group` where __allowsMultiple__ is set to False
+
+
+        :param group: Group to fetch item from
+        :return: Item for the group stored in the project
+        """
+        raise NotImplementedError()
+
     @abstractmethod
     def getItems(
         self,
