@@ -4,6 +4,7 @@ from collections import namedtuple
 from enum import Enum
 from typing import Optional
 
+import markdown
 from vortex.Tuple import Tuple
 from vortex.Tuple import TupleField
 
@@ -100,7 +101,7 @@ class StorageTuple(Tuple, metaclass=ABCMeta):
 
     @property
     def storageProject(self) -> "ContextProjectInfo":
-        return self.__ctx.project
+        return self.__ctx._projectInfo
 
     @property
     def storageKeyTuple(self) -> StorageItemKeyTuple:
@@ -110,3 +111,42 @@ class StorageTuple(Tuple, metaclass=ABCMeta):
     @property
     def storageGroup(cls) -> ItemStorageGroupEnum:
         return cls.__group__
+
+    def makeCommentHtml(self, topHeaderNum: int = 1) -> str:
+        return markdown.markdown(
+            self.makeCommentMarkdown(topHeaderNum=topHeaderNum),
+            extensions=[
+                "markdown.extensions.tables",
+                "markdown.extensions.fenced_code",
+                "markdown.extensions.sane_lists",
+            ],
+        )
+
+    def makeCommentMarkdown(self, topHeaderNum: int = 1) -> str:
+        assert hasattr(
+            self, "comment"
+        ), "This storage tuple has no comment field"
+
+        if not self.comment:
+            return ""
+
+        leastHeader = 6
+        for h in range(6, 0, -1):
+            if ("#" * h + " ") in self.comment:
+                leastHeader = h
+                break
+
+        # If highest header is <
+        headerDelta = topHeaderNum - leastHeader
+        if headerDelta == 0:
+            return self.comment
+
+        # This makes the first heading on line 0 of the text match the
+        # pattern. We then strip the final result of this whitespace
+        comment = f"\n{self.comment}"
+        for h in range(6, 0, -1):
+            comment = comment.replace(
+                "\n%s " % ("#" * h), "\n%s " % ("#" * (h + headerDelta))
+            )
+
+        return comment.lstrip()
