@@ -56,7 +56,8 @@ class ParameterMappingTuple(StorageMemberTuple):
 
 
 @ObjectStorageContext.registerItemClass
-@addStepDeclarative("Project Link")
+# TODO: AT-1107 hide unfinished Project Linking feature.
+# @addStepDeclarative("Project Link")
 @addTupleType
 class StepProjectLinkTuple(StepTuple):
     __tupleType__ = StepTupleTypeEnum.PROJECT_LINK.value
