@@ -7,6 +7,7 @@ from alembic.script import ScriptDirectory
 from sqlalchemy import create_engine
 
 from attune_project_api import ObjectStorageContext
+from attune_project_api.StorageTuple import ItemStorageGroupEnum
 
 
 logger = logging.getLogger(__name__)
@@ -54,7 +55,10 @@ def runMigrationsForStorageContext(storageContext: ObjectStorageContext):
 
             metadata = storageContext.metadata
             metadata.revision = latestRev
-            storageContext.mergeItem(metadata)
+            if storageContext.getSingularItem(ItemStorageGroupEnum.Project):
+                storageContext.mergeItem(metadata)
+            else:
+                storageContext.addItem(metadata)
             storageContext.commit("Update revision to latest")
 
             storageContext.squashAndMergeWorking(
